<?php
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Headers: Authorization, Content-Type");
header("Access-Control-Allow-Methods: POST, OPTIONS");
header("Content-Type: application/json");

if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit;
}

require_once("config.php");
require_once("database.php");
require_once("auth-check.php");

if ($decoded_token->data->role !== 'admin') {
    http_response_code(403);
    echo json_encode(["success" => false, "error" => "Yetkisiz erişim."]);
    exit;
}

$raw = file_get_contents("php://input");
$data = json_decode($raw, true);

$userId = $data["user_id"] ?? null;
$packageName = $data["package_name"] ?? null;
$start = $data["start_date"] ?? null;
$end = $data["end_date"] ?? null;

if (!$userId || !$packageName || !$start || !$end) {
    echo json_encode(["success" => false, "error" => "Eksik parametre."]);
    exit;
}

// Önce package_id'yi al
$stmt = $conn->prepare("SELECT id FROM packages WHERE name = ?");
$stmt->bind_param("s", $packageName);
$stmt->execute();
$result = $stmt->get_result();
$pkg = $result->fetch_assoc();
$stmt->close();

if (!$pkg) {
    echo json_encode(["success" => false, "error" => "Paket bulunamadı."]);
    exit;
}

$packageId = $pkg['id'];

// user_licenses tablosuna ekle
$stmt = $conn->prepare("INSERT INTO user_licenses (user_id, package_id, start_date, end_date) VALUES (?, ?, ?, ?)");
$stmt->bind_param("iiss", $userId, $packageId, $start, $end);
$success = $stmt->execute();
$stmt->close();

echo json_encode(["success" => $success]);
