<?php
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Headers: Content-Type");
header("Access-Control-Allow-Methods: POST, OPTIONS");
header("Content-Type: application/json");

if ($_SERVER["REQUEST_METHOD"] === "OPTIONS") {
    http_response_code(200);
    exit;
}

require __DIR__ . '/vendor/autoload.php';
require_once("config.php");
require_once("database.php");

use Firebase\JWT\JWT;
use Firebase\JWT\Key;

$raw = file_get_contents("php://input");
$data = json_decode($raw, true);
$token = $data["token"] ?? null;

if (!$token) {
    echo json_encode(["success" => false, "error" => "Token eksik."]);
    exit;
}

try {
    $decoded = JWT::decode($token, new Key(JWT_SECRET_KEY, JWT_ALGO));
    $userId = $decoded->sub;

    $stmt = $conn->prepare("
        SELECT ul.start_date, ul.end_date, p.name as package_name
        FROM user_licenses ul
        JOIN packages p ON ul.package_id = p.id
        WHERE ul.user_id = ?
    ");
    $stmt->bind_param("i", $userId);
    $stmt->execute();
    $result = $stmt->get_result();

    $licenses = [];
    while ($row = $result->fetch_assoc()) {
        $licenses[] = $row;
    }

    echo json_encode(["success" => true, "licenses" => $licenses]);

    $stmt->close();
    $conn->close();
} catch (Exception $e) {
    echo json_encode(["success" => false, "error" => "Token doğrulanamadı."]);
    exit;
}
