<?php
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Headers: Authorization, Content-Type");
header("Access-Control-Allow-Methods: GET, POST, OPTIONS");
header("Content-Type: application/json");

if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit;
}

require_once("config.php");
require_once("database.php");
require_once("auth-check.php");

use Firebase\JWT\JWT;
use Firebase\JWT\Key;

$decoded_token = $GLOBALS['decoded_token']; // 🔥 ZORUNLU
$user_id = $decoded_token->data->id ?? null;

if (!$user_id) {
    http_response_code(401);
    echo json_encode(["success" => false, "error" => "Geçersiz kullanıcı."]);
    exit;
}

$active_ip = $_SERVER['REMOTE_ADDR'];
$active_agent = $_SERVER['HTTP_USER_AGENT'];

$stmt = $conn->prepare("SELECT ip_address, user_agent, status, created_at FROM login_attempts WHERE user_id = ? ORDER BY created_at DESC LIMIT 10");
$stmt->bind_param("i", $user_id);
$stmt->execute();
$result = $stmt->get_result();

$logs = [];
$other_session_active = false;

while ($row = $result->fetch_assoc()) {
    $ip = $row['ip_address'];
    $agent = $row['user_agent'];

    if ($ip !== $active_ip || $agent !== $active_agent) {
        $other_session_active = true;
    }

    if ($ip === '::1' || $ip === '127.0.0.1') {
        $location = 'Yerel Makine';
        $lat = null;
        $lon = null;
    } else {
        $apiData = @file_get_contents("http://ip-api.com/json/{$ip}?fields=status,country,city,lat,lon");
        $geo = json_decode($apiData, true);
        $location = ($geo['status'] ?? '') === 'success' ? "{$geo['country']} / {$geo['city']}" : 'Konum Yok';
        $lat = $geo['lat'] ?? null;
        $lon = $geo['lon'] ?? null;
    }

    $device = 'Bilinmiyor';
    if (stripos($agent, 'Chrome') !== false) $device = 'Chrome';
    if (stripos($agent, 'Firefox') !== false) $device = 'Firefox';
    if (stripos($agent, 'Opera') !== false) $device = 'Opera';
    if (stripos($agent, 'Android') !== false) $device = 'Android';
    if (stripos($agent, 'iPhone') !== false) $device = 'iPhone';
    if (stripos($agent, 'Windows') !== false) $device .= ' / Windows';
    if (stripos($agent, 'Mac') !== false) $device .= ' / Mac';

    $row['location'] = $location;
    $row['lat'] = $lat;
    $row['lon'] = $lon;
    $row['device'] = $device;

    $logs[] = $row;
}

echo json_encode([
    "success" => true,
    "other_session" => $other_session_active,
    "data" => $logs
]);
