<?php
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Headers: Authorization, Content-Type");
header("Access-Control-Allow-Methods: POST, OPTIONS");
header("Content-Type: application/json");

if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit;
}

require_once("config.php");
require_once("database.php");
require_once("auth-check.php");

if ($decoded_token->data->role !== 'admin') {
    http_response_code(403);
    echo json_encode(["success" => false, "error" => "Yetkisiz erişim."]);
    exit;
}

$raw = file_get_contents("php://input");
$data = json_decode($raw, true);
$userId = $data["id"] ?? null;

if (!$userId) {
    echo json_encode(["success" => false, "error" => "Kullanıcı ID eksik."]);
    exit;
}

$stmt = $conn->prepare("SELECT ip_address, user_agent, status, created_at FROM login_attempts WHERE user_id = ? ORDER BY created_at DESC LIMIT 30");
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();

$logs = [];
while ($row = $result->fetch_assoc()) {
    $ip = $row['ip_address'];
    $agent = $row['user_agent'];
    $status = $row['status'];
    $created = $row['created_at'];

    // Lokasyon
    if ($ip === '::1' || $ip === '127.0.0.1') {
        $location = 'Yerel Makine';
    } else {
        $geo = @file_get_contents("http://ip-api.com/json/{$ip}?fields=status,country,city");
        $geoData = json_decode($geo, true);
        $location = $geoData && $geoData['status'] === 'success'
            ? "{$geoData['country']} / {$geoData['city']}"
            : 'Konum Bilinmiyor';
    }

    // Tarayıcı
    $device = 'Bilinmiyor';
    if (stripos($agent, 'Chrome') !== false) $device = 'Chrome';
    elseif (stripos($agent, 'Firefox') !== false) $device = 'Firefox';
    elseif (stripos($agent, 'Opera') !== false) $device = 'Opera';
    elseif (stripos($agent, 'Edge') !== false) $device = 'Edge';
    elseif (stripos($agent, 'Windows') !== false) $device .= ' / Windows';
    elseif (stripos($agent, 'Android') !== false) $device = 'Android';
    elseif (stripos($agent, 'iPhone') !== false) $device = 'iPhone';

    $logs[] = [
        'ip' => $ip,
        'location' => $location,
        'device' => $device,
        'status' => $status,
        'created_at' => $created
    ];
}

echo json_encode(["success" => true, "logs" => $logs]);
