<?php
require_once("config.php");
require_once("database.php");
require_once("vendor/autoload.php");

use Firebase\JWT\JWT;
use Firebase\JWT\Key;

header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Headers: Content-Type");
header("Content-Type: application/json");

$ip = $_SERVER['REMOTE_ADDR'];
$user_agent = $_SERVER['HTTP_USER_AGENT'];
$data = json_decode(file_get_contents("php://input"), true);

$identifier = $data["identifier"] ?? null;
$password = $data["password"] ?? null;
$remember = $data["remember"] ?? false;

if (!$identifier || !$password) {
    echo json_encode(["success" => false, "error" => "Eksik veri gönderildi."]);
    exit;
}

// Ban kontrolü
$stmt = $conn->prepare("SELECT ban_expiration FROM banned_ips WHERE ip_address = ? AND ban_expiration > NOW()");
$stmt->bind_param("s", $ip);
$stmt->execute();
$stmt->store_result();

if ($stmt->num_rows > 0) {
    $stmt->bind_result($banExpiration);
    $stmt->fetch();
    echo json_encode([
        "success" => false,
        "banned" => true,
        "remaining_seconds" => strtotime($banExpiration) - time(),
        "error" => "Çok fazla hatalı giriş yaptınız. Lütfen bekleyin."
    ]);
    exit;
}
$stmt->close();

// Kullanıcı kontrolü
$stmt = $conn->prepare("SELECT * FROM users WHERE email = ? OR username = ? LIMIT 1");
$stmt->bind_param("ss", $identifier, $identifier);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();
$stmt->close();

if ($user && password_verify($password, $user["password"])) {
    // Giriş başarılı
    $conn->query("DELETE FROM banned_ips WHERE ip_address = '$ip'");
    $conn->query("DELETE FROM login_attempts WHERE ip_address = '$ip'");

    $log = $conn->prepare("INSERT INTO login_attempts (user_id, ip_address, user_agent, status, created_at) VALUES (?, ?, ?, 'success', NOW())");
    $log->bind_param("iss", $user["id"], $ip, $user_agent);
    $log->execute();
    $log->close();

    $payload = [
        "iss" => "xtool",
        "aud" => "xtool-users",
        "iat" => time(),
        "exp" => time() + JWT_EXPIRE_TIME,
        "sub" => $user["id"],
        "data" => [
            "id" => $user["id"],
            "username" => $user["username"],
            "email" => $user["email"],
            "name" => $user["name"],
            "phone" => $user["phone"],
            "country_city" => $user["country_city"],
            "balance" => $user["balance"],
            "created_at" => $user["created_at"],
            "role" => $user["role"]
        ]
    ];

    $jwt = JWT::encode($payload, JWT_SECRET_KEY, JWT_ALGO);

    if ($remember) {
        setcookie("remember_identifier", $identifier, time() + (86400 * 30), "/");
    }

    echo json_encode(["success" => true, "token" => $jwt, "message" => "Giriş başarılı!"]);
    exit;
}

// Başarısız giriş
$null = null;
$log = $conn->prepare("INSERT INTO login_attempts (user_id, ip_address, user_agent, status, created_at) VALUES (?, ?, ?, 'fail', NOW())");
$log->bind_param("iss", $null, $ip, $user_agent);
$log->execute();
$log->close();

$check = $conn->prepare("SELECT COUNT(*) as attempts FROM login_attempts WHERE ip_address = ? AND status = 'fail'");
$check->bind_param("s", $ip);
$check->execute();
$check->bind_result($attempts);
$check->fetch();
$check->close();

if ($attempts >= 3) {
    $banExpiration = date("Y-m-d H:i:s", time() + 86400);
    $stmt = $conn->prepare("REPLACE INTO banned_ips (ip_address, ban_expiration) VALUES (?, ?)");
    $stmt->bind_param("ss", $ip, $banExpiration);
    $stmt->execute();
    $stmt->close();

    echo json_encode([
        "success" => false,
        "banned" => true,
        "remaining_seconds" => 86400,
        "error" => "3 hatalı girişten dolayı IP 24 saat banlandı."
    ]);
    exit;
}

echo json_encode(["success" => false, "error" => "Kullanıcı adı/e-posta veya şifre hatalı."]);
