<?php
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Headers: Authorization, Content-Type");
header("Access-Control-Allow-Methods: POST, OPTIONS");
header("Content-Type: application/json");

if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit;
}

require_once("config.php");
require_once("database.php");

$data = json_decode(file_get_contents("php://input"), true);

$email = trim($data['email'] ?? '');
$password = trim($data['password'] ?? '');
$code = trim($data['code'] ?? '');

if (!$email || !$password || !$code) {
    echo json_encode(["success" => false, "error" => "E-posta, şifre ve kod gereklidir."]);
    exit;
}

// Kullanıcıyı bul
$stmt = $conn->prepare("SELECT id FROM users WHERE email = ?");
$stmt->bind_param("s", $email);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();
$stmt->close();

if (!$user) {
    echo json_encode(["success" => false, "error" => "Kullanıcı bulunamadı."]);
    exit;
}

// Kod kontrolü
$stmt = $conn->prepare("
  SELECT * FROM password_resets
  WHERE user_id = ? AND code = ? AND expires_at >= NOW()
");
$stmt->bind_param("is", $user['id'], $code);
$stmt->execute();
$result = $stmt->get_result();
$valid = $result->fetch_assoc();
$stmt->close();

if (!$valid) {
    echo json_encode(["success" => false, "error" => "Kod geçersiz veya süresi dolmuş."]);
    exit;
}

// Şifreyi güncelle
$hashed = password_hash($password, PASSWORD_DEFAULT);
$stmt = $conn->prepare("UPDATE users SET password = ? WHERE id = ?");
$stmt->bind_param("si", $hashed, $user['id']);
$stmt->execute();
$stmt->close();

// Reset kodunu sil
$conn->query("DELETE FROM password_resets WHERE user_id = {$user['id']}");

echo json_encode(["success" => true]);
